Package: depmap
Type: Package
Title: Cancer Dependency Map Data Package
Version: 1.23.0
Authors@R: c(person(given = "Laurent", family = "Gatto",
                    email = "laurent.gatto@uclouvain.be",
                    comment = c(ORCID = "0000-0002-1520-2268"),
                    role = c("cre", "aut")),
            person(given = "Theo", family = "Killian",
                    role = "aut"),
            person(given = "Alexander", family = "Peltzer", role = "ctb",
                    comment = c(ORCID = "0000-0002-6503-2180")))
Description: The depmap package is a data package that accesses datsets from the
    Broad Institute DepMap cancer dependency study using ExperimentHub. Datasets
    from the most current release are available, including RNAI and CRISPR-Cas9
    gene knockout screens quantifying the genetic dependency for select cancer
    cell lines. Additional datasets are also available pertaining to the log
    copy number of genes for select cell lines, protein expression of cell lines
    as measured by reverse phase protein lysate microarray (RPPA), 'Transcript
    Per Million' (TPM) data, as well as supplementary datasets which contain
    metadata and mutation calls for the other datasets found in the current
    release. The 19Q3 release adds the drug_dependency dataset, that contains
    cancer cell line dependency data with respect to drug and drug-candidate
    compounds. The 20Q2 release adds the proteomic dataset that contains
    quantitative profiling of proteins via mass spectrometry. This package will
    be updated on a quarterly basis to incorporate the latest Broad Institute
    DepMap Public cancer dependency datasets. All data made available in this
    package was generated by the Broad Institute DepMap for research purposes
    and not intended for clinical use. This data is distributed under the
    Creative Commons license (Attribution 4.0 International (CC BY 4.0)).
Depends: R (>= 4.1.0), methods, dplyr
Imports: utils, ExperimentHub, AnnotationHub, BiocFileCache, httr2,
        curl, tibble
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.3.1
Suggests: knitr, rmarkdown, BiocStyle, viridis, gridExtra, ggplot2,
        readr, stringr, tidyverse, magick
VignetteBuilder: knitr
biocViews: ExperimentHub, ExperimentData, ReproducibleResearch,
        RepositoryData, AssayDomainData, CopyNumberVariationData,
        DiseaseModel, CancerData, BreastCancerData, ColonCancerData,
        KidneyCancerData, LeukemiaCancerData, LungCancerData,
        OvarianCancerData, ProstateCancerData, OrganismData,
        Homo_sapiens_Data, PackageTypeData, SpecimenSource,
        CellCulture, Genome, Proteome, StemCell, Tissue
git_url: https://git.bioconductor.org/packages/depmap
git_branch: devel
git_last_commit: bc169e5
git_last_commit_date: 2025-04-15
Repository: Bioconductor 3.22
Date/Publication: 2025-04-17
NeedsCompilation: no
Packaged: 2025-04-17 15:23:15 UTC; biocbuild
Author: Laurent Gatto [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-1520-2268>),
  Theo Killian [aut],
  Alexander Peltzer [ctb] (ORCID:
    <https://orcid.org/0000-0002-6503-2180>)
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
