# Generated by roxygen2: do not edit by hand

export(DepMapDataset)
export(DepMapFiles)
export(depmap_RPPA)
export(depmap_TPM)
export(depmap_achilles)
export(depmap_copyNumber)
export(depmap_crispr)
export(depmap_drug_sensitivity)
export(depmap_gene_summary)
export(depmap_metadata)
export(depmap_mutationCalls)
export(depmap_proteomic)
export(depmap_release)
export(depmap_rnai)
export(dmCache)
export(dmFileNames)
export(dmNumFiles)
export(dmTitle)
export(dmfiles)
export(dmget)
export(dmsets)
import(dplyr)
import(methods)
importFrom(AnnotationHub,query)
importFrom(BiocFileCache,BiocFileCache)
importFrom(BiocFileCache,bfcadd)
importFrom(BiocFileCache,bfcquery)
importFrom(BiocFileCache,bfcrpath)
importFrom(ExperimentHub,ExperimentHub)
importFrom(ExperimentHub,createHubAccessors)
importFrom(curl,has_internet)
importFrom(httr2,req_perform)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(tibble,as_tibble)
importFrom(tools,R_user_dir)
importFrom(utils,read.csv)
