% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depmap.R
\name{depmap_release}
\alias{depmap_release}
\title{Returns the depmap release}
\usage{
depmap_release()
}
\value{
\code{character(1)} with the depmap release
}
\description{
Returns the depmap release
}
